// ===========================================================================
// CONTENT  : CLASS JOI
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 10/06/2001
// HISTORY  :
//  10/06/2001  duma  CREATED
//
// Copyright (c) 2001-2002, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package joi ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.PrintWriter;
import java.io.Writer;

import org.pf.joi.AbstractObjectSpy;
import org.pf.joi.Inspector;
import org.pf.joi.xml.ObjectPrinter;

/**
 * This class provides static methods for the general available
 * inspector functionality access.
 * It also initializes the JOI extionsions. Actually that is the XML export
 * provider.
 * <br>
 * Therefore it requires an XML parser package compliant to JAXP 1.1 such as 
 * <a href="http://xml.apache.org/xerces2-j/index.html" target="_blank">
 * Xerces</a>
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class JOI
{
  // =========================================================================
  // PUBLIC CLASS METHODS
  // =========================================================================
	/**
	 * Inspect the given object.   <br>
	 * That means to display the internal state of the given object's attributes.
	 * This method is always using the basic inspector.
	 *
	 * @param obj The object to look inside
	 */
	public static Inspector basicInspect( Object obj )
	{
		return org.pf.joi.Inspector.basicInspect( obj ) ;
	} // basicInspect()

  // -------------------------------------------------------------------------

	/**
	 * Inspect the given object.   <br>
	 * That means to display the internal state of the given object's attributes.
	 * This method is always using the basic inspector.
	 *
   * @param name The name of the object in its program context
	 * @param obj The object to look inside
	 */
	public static Inspector basicInspect( String name, Object obj )
	{
		return org.pf.joi.Inspector.basicInspect( name, obj ) ;
	} // basicInspect()

  // -------------------------------------------------------------------------

	/**
	 * Inspect the given object.   <br>
	 * That means to display the internal state of the given object's attributes.
	 * The inspector can be a specialized one for the class of the given object.
	 *
	 * @param obj The object to look inside
	 */
	public static Inspector inspect( Object obj )
	{
		return org.pf.joi.Inspector.inspect( obj ) ;
	} // inspect()

  // -------------------------------------------------------------------------

	/**
	 * Inspect the given object.   <br>
	 * That means to display the internal state of the given object's attributes.
	 * The inspector can be a specialized one for the class of the given object.
	 *
   * @param name The name of the object in its program context
	 * @param obj The object to look inside
	 */
	public static Inspector inspect( String name, Object obj )
	{
		return org.pf.joi.Inspector.inspect( name, obj ) ;
	} // inspect()

  // -------------------------------------------------------------------------

	/**
	 * Inspect the given object like in basicInspect().   <br>
	 * But this method doesn't return until the inspector and all its
   * sub-inspectors are closed again.
	 *
	 * @param obj The object to look inside
	 */
	public static void basicInspectWait( Object obj )
	{
    org.pf.joi.Inspector.basicInspectWait( obj ) ;
	} // basicInspectWait()

  // -------------------------------------------------------------------------

	/**
	 * Inspect the given object like in basicInspect().   <br>
	 * But this method doesn't return until the inspector and all its
   * sub-inspectors are closed again.
	 *
   * @param name The name of the object in its program context
	 * @param obj The object to look inside
	 */
	public static void basicInspectWait( String name, Object obj )
	{
    org.pf.joi.Inspector.basicInspectWait( name, obj ) ;
	} // basicInspectWait()

  // -------------------------------------------------------------------------

	/**
	 * Inspect the given object like in inspect().   <br>
	 * But this method doesn't return until the inspector and all its
   * sub-inspectors are closed again.
	 *
	 * @param obj The object to look inside
	 */
	public static void inspectWait( Object obj )
	{
    org.pf.joi.Inspector.inspectWait( obj ) ;
	} // inspectWait()

  // -------------------------------------------------------------------------

	/**
	 * Inspect the given object like in inspect().   <br>
	 * But this method doesn't return until the inspector and all its
   * sub-inspectors are closed again.
	 *
   * @param name The name of the object in its program context
	 * @param obj The object to look inside
	 */
	public static void inspectWait( String name, Object obj )
	{
    org.pf.joi.Inspector.inspectWait( name, obj ) ;
	} // inspectWait()

  // -------------------------------------------------------------------------

	/**
	 * Returns the object spy wrapper for the given object.   <br>
	 * It will be wrapped by the basic inspector.
   *
	 * @param obj The object to look inside
	 */
	public static AbstractObjectSpy getBasicObjectSpy( Object obj )
	{
		return org.pf.joi.Inspector.getBasicObjectSpy( obj ) ;
	} // getBasicObjectSpy()

  // -------------------------------------------------------------------------

	/**
	 * Returns the object spy wrapper for the given object.   <br>
	 * It will be wrapped by the basic inspector.
   *
   * @param name The name of the object in its program context
	 * @param obj The object to look inside
	 */
	public static AbstractObjectSpy getBasicObjectSpy( String name, Object obj )
	{
		return org.pf.joi.Inspector.getBasicObjectSpy( name, obj ) ;
	} // getBasicObjectSpy()

  // -------------------------------------------------------------------------

	/**
	 * Returns the object spy wrapper for the given object.   <br>
	 * It will be wrapped by the inspector that is registerd for
   * the object's type.
   *
	 * @param obj The object to look inside
	 */
	public static AbstractObjectSpy getObjectSpy( Object obj )
	{
		return org.pf.joi.Inspector.getObjectSpy( obj ) ;
	} // getObjectSpy()

  // -------------------------------------------------------------------------

	/**
	 * Returns the object spy wrapper for the given object.   <br>
	 * It will be wrapped by the inspector that is registerd for
   * the object's type.
   *
   * @param name The name the object has in the program context
	 * @param obj The object to look inside
	 */
	public static AbstractObjectSpy getObjectSpy( String name, Object obj )
	{
		return org.pf.joi.Inspector.getObjectSpy( name, obj ) ;
	} // getObjectSpy()

  // -------------------------------------------------------------------------

	/**
	 * Writes the given object as XML representation to stdout.
	 */
  public static void printXml( Object obj )
  {
    printXml( null, obj ) ;
  } // printXml()

  // -------------------------------------------------------------------------

	/**
	 * Writes the given object with the specified name 
	 * as XML representation to stdout.
	 */
  public static void printXml( String name, Object obj )
  {
    printXml( name, obj, new PrintWriter( System.out ) ) ;
  } // printXml()

  // -------------------------------------------------------------------------

	/**
	 * Writes the given object as XML representation to the given writer.
	 */
  public static void printXml( Object obj, Writer writer )
  {
    printXml( null, obj, writer ) ;
  } // printXml()

  // -------------------------------------------------------------------------

	/**
	 * Writes the given object with the specified name 
	 * as XML representation to the given writer.
	 */
  public static void printXml( String name, Object obj, Writer writer )
  {
    ObjectPrinter printer   = null ;

    printer = new ObjectPrinter() ;
    printer.printObject( name, obj, writer ) ;
  } // printXml()

  // -------------------------------------------------------------------------

	/**
	 * Writes the given object's XML representation to stdout 
	 * using the basic inspector.
	 */
  public static void printBasicXml( Object obj )
  {
    printXml( null, obj ) ;
  } // printBasicXml()

  // -------------------------------------------------------------------------

	/**
	 * Writes the given object's XML representation with the specified name 
	 * to stdout using the basic inspector.
	 */
  public static void printBasicXml( String name, Object obj )
  {
    printBasicXml( name, obj, new PrintWriter( System.out ) ) ;
  } // printBasicXml()

  // -------------------------------------------------------------------------

	/**
	 * Writes the given object's XML representation 
	 * to stdout using the basic inspector.
	 */
  public static void printBasicXml( Object obj, Writer writer )
  {
    printBasicXml( null, obj, writer ) ;
  } // printBasicXml()

  // -------------------------------------------------------------------------

	/**
	 * Writes the given object's XML representation with the specified name 
	 * to the given writer using the basic inspector.
	 */
  public static void printBasicXml( String name, Object obj, Writer writer )
  {
    ObjectPrinter printer   = null ;

    printer = new ObjectPrinter() ;
    printer.printBasicObject( name, obj, writer ) ;
  } // printBasicXml()

  // -------------------------------------------------------------------------

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * No public constructor for this class
   */
  private JOI()
  {
    super() ;
  } // JOI()

} // class JOI