// ===========================================================================
// CONTENT  : CLASS ObjectPrinter
// AUTHOR   : Manfred Duchrow
// VERSION  : 2.0 - 20/03/2003
// HISTORY  :
//  21/07/2001  duma  CREATED
//	15/03/2003	duma	changed	->	removed dependencies on xerces
//
// Copyright (c) 2001-2003, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pf.joi.xml;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.PrintWriter;
import java.io.Writer;

import org.pf.joi.AbstractObjectSpy;
import org.pf.joi.Inspector;
import org.pf.six.Element;
import org.pf.six.XmlStreamWriter;

/**
 * Prints the internal state of an object as XML stream to given writers.
 *
 * @author Manfred Duchrow
 * @version 2.0
 */
public class ObjectPrinter
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================

  // =========================================================================
  // CLASS METHODS
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public ObjectPrinter()
  {
    super() ;
  } // ObjectPrinter()

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Prints the given object as XML stream to stdout.
   * 
   * @param name An arbitrary name for the inspected object
   * @param object The object to be printed
   */
  public void printObject( String name, Object object )
  {
    this.printObject( name, object, new PrintWriter( System.out ) );
  } // printObject()

  // -------------------------------------------------------------------------

  /**
   * Prints the given object as XML stream to the specified writer.
   * 
   * @param object The object to be printed
   * @param writer The destination of the XML output
   */
  public void printObject( Object object, Writer writer )
  {
    this.printObject( null, object, writer ) ;
  } // printObject()

  // -------------------------------------------------------------------------

  /**
   * Prints the given object as XML stream to the specified writer.
   * 
   * @param name An arbitrary name for the inspected object
   * @param object The object to be printed
   * @param writer The destination of the XML output
   */
  public void printObject( String name, Object object, Writer writer )
  {
    AbstractObjectSpy objectSpy   = null ;

    objectSpy = Inspector.getObjectSpy( name, object ) ;
    this.appendObjectSpy( objectSpy, writer );
  } // printObject()

  // -------------------------------------------------------------------------

  /**
   * Prints the given object as XML stream to the specified writer
   * whereas it will use the basic inspector rather than the "clever"
   * inspector.
   * 
   * @param name An arbitrary name for the inspected object
   * @param object The object to be printed
   * @param writer The destination of the XML output 
   */
  public void printBasicObject( String name, Object object, Writer writer )
  {
    AbstractObjectSpy objectSpy   = null ;

    objectSpy = Inspector.getBasicObjectSpy( name, object ) ;
    this.appendObjectSpy( objectSpy, writer );
  } // printBasicObject()

  // -------------------------------------------------------------------------

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

  protected void appendObjectSpy( AbstractObjectSpy objectSpy, Writer writer )
  {
    try
    {
      this.appendObjectSpyTo( objectSpy, writer ) ;
    }
    catch ( Exception ex )
    {
      ex.printStackTrace();
    }
  } // appendObjectSpy

  // -------------------------------------------------------------------------

  protected void appendObjectSpyTo( AbstractObjectSpy objectSpy, Writer writer )
    throws Exception
  {
    XMLObjectExporter exporter  = null ;
    Element root ;
    Element[] elements ;

    if ( writer == null )
      throw new Exception( "No writer specified!" ) ;

    exporter = new XMLObjectExporter() ;
    root = exporter.createXMLTree( objectSpy ) ;
    elements = root.find( XMLTags.tag_InspectedObject() ) ;
    
    if ( elements.length > 0 )
    {
			XmlStreamWriter.writeSIXElement( elements[0], writer ) ;
    }
  } // appendObjectSpyTo()

  // -------------------------------------------------------------------------

} // class ObjectPrinter